channel

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 12, 2025 License: AGPL-3.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type CloseRequest

type CloseRequest struct {
	// map[channel_point]force_close
	Channels map[string]bool
	SatvB    uint64
}

CloseRequest contains the information necessary to close a set of channels.

type Manager

type Manager interface {
	Open(ctx context.Context, req OpenRequest) error
	Close(ctx context.Context, req CloseRequest) error
	// Splice(channelID uint64, amount int64) error
	UpdatePolicy(ctx context.Context, req UpdatePolicyRequest) error
}

Manager handles the opening, closing an re-sizing of channels.

func NewManager

func NewManager(config config.ChannelManager, lnd lightning.Client) Manager

NewManager returns a channel manager that opens, closes and re-sizes channels.

type OpenRequest

type OpenRequest struct {
	// map[public_key]funding_amount
	Nodes map[string]uint64
	SatvB uint64
}

OpenRequest contains the information necessary to open a set of channels.

type UpdatePolicyRequest added in v0.2.0

type UpdatePolicyRequest struct {
	ChannelPoint  string
	BaseFeeMsat   uint64
	FeeRatePPM    uint64
	MaxHTLCMsat   uint64
	TimeLockDelta uint64
}

UpdatePolicyRequest contains the information necessary to update the policy of a channel.

Jump to