Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CloseRequest ¶
CloseRequest contains the information necessary to close a set of channels.
type Manager ¶
type Manager interface {
Open(ctx context.Context, req OpenRequest) error
Close(ctx context.Context, req CloseRequest) error
// Splice(channelID uint64, amount int64) error
UpdatePolicy(ctx context.Context, req UpdatePolicyRequest) error
}
Manager handles the opening, closing an re-sizing of channels.
func NewManager ¶
func NewManager(config config.ChannelManager, lnd lightning.Client) Manager
NewManager returns a channel manager that opens, closes and re-sizes channels.
type OpenRequest ¶
OpenRequest contains the information necessary to open a set of channels.
Click to show internal directories.
Click to hide internal directories.